summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 69b0d49)
raw | patch | inline | side by side (parent: 69b0d49)
author | Florian Forster <octo@collectd.org> | |
Fri, 27 Nov 2015 09:03:54 +0000 (10:03 +0100) | ||
committer | Florian Forster <octo@collectd.org> | |
Fri, 27 Nov 2015 09:03:54 +0000 (10:03 +0100) |
This way the option name is consistent with the name used by the cURL
plugins.
Sorry for previous comments in #1345 that pushed towards copying Apache
HTTPd's naming schema -- being consistent within collectd is more
important.
plugins.
Sorry for previous comments in #1345 that pushed towards copying Apache
HTTPd's naming schema -- being consistent within collectd is more
important.
src/collectd.conf.pod | patch | blob | history | |
src/mqtt.c | patch | blob | history |
diff --git a/src/collectd.conf.pod b/src/collectd.conf.pod
index ee05c3a8ee8cdebc7279fa29aafac38b9b014820..baae0274f2123ba94add34c4cc48b79e5d04e8bb 100644 (file)
--- a/src/collectd.conf.pod
+++ b/src/collectd.conf.pod
@@ -3347,7 +3347,7 @@ Configures the topic(s) to subscribe to. You can use the single level C<+> and
multi level C<#> wildcards. Defaults to B<collectd/#>, i.e. all topics beneath
the B<collectd> branch.
-=item B<CACertificateFile> I<file>
+=item B<CACert> I<file>
Path to the PEM-encoded CA certificate file. Setting this option enables TLS
communication with the MQTT broker, and as such, B<Port> should be the TLS-enabled
diff --git a/src/mqtt.c b/src/mqtt.c
index 403b0d31e2a38ccdc2c26e5cf29516236249ee3b..f8c1e0ef9b4ae7da5ee84de5e8f97bfebb431241 100644 (file)
--- a/src/mqtt.c
+++ b/src/mqtt.c
* StoreRates true
* Retain false
* QoS 0
* CACertificateFile "ca.pem" Enables TLS if set
* CertificateFile "client-cert.pem" optional
* CertificateKeyFile "client-key.pem" optional
* TLSprotocol "tlsv1.2" optional
cf_util_get_boolean (child, &conf->store_rates);
else if (strcasecmp ("Retain", child->key) == 0)
cf_util_get_boolean (child, &conf->retain);
- else if (strcasecmp ("CACertificateFile", child->key) == 0)
+ else if (strcasecmp ("CACert", child->key) == 0)
cf_util_get_string (child, &conf->cacertificatefile);
else if (strcasecmp ("CertificateFile", child->key) == 0)
cf_util_get_string (child, &conf->certificatefile);
@@
* Retain false
* QoS 0
- * CACertificateFile "ca.pem" Enables TLS if set
+ * CACert "ca.pem" Enables TLS if set
* CertificateFile "client-cert.pem" optional
* CertificateKeyFile "client-key.pem" optional